@@ -299,6 +299,7 @@ open_calendar (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,
 	d(printf("ecbe_open_calendar(%p, %p, %sonly if exists, user=%s, pass=%s)\n", backend, cal, only_if_exists?"":"not ", username?username:"(null)", password?password:"(null)"));
 
 	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (backend));
+	printf ("uri of cal to open is : %s\n", uristr);
 
 	g_mutex_lock (cbex->priv->open_lock);
 
@@ -1103,7 +1104,6 @@ set_mode (ECalBackend *backend, CalMode mode)
 			cbex->folder = exchange_account_get_folder (account, uristr);
 			/* FIXME : Test if available for read already */
 			priv->read_only = FALSE;
-			exchange_account_set_online (account);
 			priv->mode = CAL_MODE_REMOTE;
 			/* FIXME : Check if online and check if authentication
 				is needed */
@@ -1120,7 +1120,6 @@ set_mode (ECalBackend *backend, CalMode mode)
 			cbex->folder = exchange_account_get_folder (account, uristr);
 			priv->mode = CAL_MODE_LOCAL;
 			priv->read_only = TRUE;
-			exchange_account_set_offline (account);
 			e_cal_backend_notify_mode (backend, 
 				GNOME_Evolution_Calendar_CalListener_MODE_SET,
 				GNOME_Evolution_Calendar_MODE_LOCAL);
