@@ -17,6 +17,9 @@ extern "C" {
 #include <camel/camel-offline-store.h>
 #include "camel-stub.h"
 
+#define EX_CAMEL_SERVICE_LOCK(f, l) (g_mutex_lock(((CamelExchangeStore *)f)->l))
+#define EX_CAMEL_SERVICE_UNLOCK(f, l) (g_mutex_unlock(((CamelExchangeStore *)f)->l))
+
 #define CAMEL_EXCHANGE_STORE_TYPE     (camel_exchange_store_get_type ())
 #define CAMEL_EXCHANGE_STORE(obj)     (CAMEL_CHECK_CAST((obj), CAMEL_EXCHANGE_STORE_TYPE, CamelExchangeStore))
 #define CAMEL_EXCHANGE_STORE_CLASS(k) (CAMEL_CHECK_CLASS_CAST ((k), CAMEL_EXCHANGE_STORE_TYPE, CamelExchangeStoreClass))
@@ -31,6 +34,9 @@ typedef struct {
 	GHashTable *folders;
 	GMutex *folders_lock;
 
+	gboolean stub_connected;
+	GMutex *connect_lock;
+
 } CamelExchangeStore;
 
 typedef struct {
